@@ -1,3 +1,4 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*************************************************************************
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
@@ -44,9 +45,7 @@
 #include "DrawController.hxx"
 #include <com/sun/star/beans/XPropertySet.hpp>
 
-#ifndef _SVT_CONTROLDIMS_HRC_
 #include <svtools/controldims.hrc>
-#endif
 #include <svx/gallery.hxx>
 #include <unotools/pathoptions.hxx>
 #include <vcl/msgbox.hxx>
@@ -133,9 +132,9 @@ struct TransitionEffect
         mfDuration = 2.0;
         mnTime = 0;
         mePresChange = PRESCHANGE_MANUAL;
-        mbSoundOn = FALSE;
-        mbLoopSound = FALSE;
-        mbStopSound = FALSE;
+        mbSoundOn = sal_False;
+        mbLoopSound = sal_False;
+        mbStopSound = sal_False;
 
         mbEffectAmbiguous = false;
         mbDurationAmbiguous = false;
@@ -184,12 +183,12 @@ struct TransitionEffect
         {
             if( mbStopSound )
             {
-                rOutPage.SetStopSound( TRUE );
-                rOutPage.SetSound( FALSE );
+                rOutPage.SetStopSound( sal_True );
+                rOutPage.SetSound( sal_False );
             }
             else
             {
-                rOutPage.SetStopSound( FALSE );
+                rOutPage.SetStopSound( sal_False );
                 rOutPage.SetSound( mbSoundOn );
                 rOutPage.SetSoundFile( maSound );
             }
@@ -223,9 +222,9 @@ struct TransitionEffect
 
     // other settings
     double		mfDuration;
-    ULONG       mnTime;
+    sal_uLong       mnTime;
     PresChange  mePresChange;
-    BOOL        mbSoundOn;
+    sal_Bool        mbSoundOn;
     String      maSound;
     bool		mbLoopSound;
     bool		mbStopSound;
@@ -265,9 +264,9 @@ void lcl_CreateUndoForPages(
     const ::sd::slidesorter::SharedPageSelection& rpPages,
     ::sd::ViewShellBase& rBase )
 {
-    ::sd::DrawDocShell* pDocSh	= rBase.GetDocShell();
-    SfxUndoManager* pManager	= pDocSh->GetUndoManager();
-    SdDrawDocument*	pDoc		= pDocSh->GetDoc();
+    ::sd::DrawDocShell* pDocSh	    = rBase.GetDocShell();
+    ::svl::IUndoManager* pManager   = pDocSh->GetUndoManager();
+    SdDrawDocument*	pDoc		    = pDocSh->GetDoc();
     if( pManager && pDocSh && pDoc )
     {
         String aComment( SdResId(STR_UNDO_SLIDE_PARAMS) );
@@ -346,7 +345,7 @@ struct lcl_EqualsSoundFileName : public ::std::unary_function< String, bool >
     {
         // note: formerly this was a case insensitive search for all
         // platforms. It seems more sensible to do this platform-dependent
-#if defined( WIN ) || defined( WNT )
+#if defined( WNT )
         return maStr.EqualsIgnoreCaseAscii( rStr );
 #else
         return maStr.Equals( rStr );
@@ -496,7 +495,6 @@ SlideTransitionPane::SlideTransitionPane(
 
     // update control states before adding handlers
     updateLayout();
-    //    updateSoundList();
     updateControls();
 
     // set handlers
@@ -546,7 +544,6 @@ void SlideTransitionPane::onChangeCurrentPage()
 {
     ::sd::slidesorter::SlideSorterViewShell * pSlideSorterViewShell
         = ::sd::slidesorter::SlideSorterViewShell::GetSlideSorter(mrBase);
-//    DBG_ASSERT( pSlideSorterViewShell, "No Slide-Sorter available" );
     ::boost::shared_ptr<sd::slidesorter::SlideSorterViewShell::PageSelection> pSelection;
 
     if( pSlideSorterViewShell )
@@ -839,7 +836,7 @@ void SlideTransitionPane::updateControls()
             if( lcl_findSoundInList( maSoundList, aEffect.maSound, nPos ))
             {
                 // skip first three entries
-                maLB_SOUND.SelectEntryPos( (USHORT)nPos + 3 );
+                maLB_SOUND.SelectEntryPos( (sal_uInt16)nPos + 3 );
                 maCurrentSoundFile = aEffect.maSound;
             }
         }
@@ -860,8 +857,8 @@ void SlideTransitionPane::updateControls()
 
     if( aEffect.mbPresChangeAmbiguous )
     {
-        maRB_ADVANCE_ON_MOUSE.Check( FALSE );
-        maRB_ADVANCE_AUTO.Check( FALSE );
+        maRB_ADVANCE_ON_MOUSE.Check( sal_False );
+        maRB_ADVANCE_AUTO.Check( sal_False );
     }
     else
     {
@@ -890,7 +887,6 @@ void SlideTransitionPane::updateControlState()
 
     maPB_APPLY_TO_ALL.Enable( mbHasSelection );
     maPB_PLAY.Enable( mbHasSelection );
-//     maPB_SLIDE_SHOW.Enable( TRUE );
     maCB_AUTO_PREVIEW.Enable( mbHasSelection );
 }
 
@@ -964,7 +960,7 @@ void SlideTransitionPane::openSoundFileDialog()
                 String aStr( sal_Unicode( '%' ));
                 aStrWarning.SearchAndReplace( aStr , aFile );
                 WarningBox aWarningBox( NULL, WB_3DLOOK | WB_RETRY_CANCEL, aStrWarning );
-                aWarningBox.SetModalInputMode (TRUE);
+                aWarningBox.SetModalInputMode (sal_True);
                 bQuitLoop = (aWarningBox.Execute() != RET_RETRY);
 
                 bValidSoundFile = false;
@@ -973,7 +969,7 @@ void SlideTransitionPane::openSoundFileDialog()
 
         if( bValidSoundFile )
             // skip first three entries in list
-            maLB_SOUND.SelectEntryPos( (USHORT)nPos + 3 );
+            maLB_SOUND.SelectEntryPos( (sal_uInt16)nPos + 3 );
     }
 
     if( ! bValidSoundFile )
@@ -982,7 +978,7 @@ void SlideTransitionPane::openSoundFileDialog()
         {
             tSoundListType::size_type nPos = 0;
             if( lcl_findSoundInList( maSoundList, maCurrentSoundFile, nPos ))
-                maLB_SOUND.SelectEntryPos( (USHORT)nPos + 3 );
+                maLB_SOUND.SelectEntryPos( (sal_uInt16)nPos + 3 );
             else
                 maLB_SOUND.SelectEntryPos( 0 );  // NONE
         }
@@ -1041,9 +1037,7 @@ impl::TransitionEffect SlideTransitionPane::getTransitionEffectFromControls() co
             aResult.mePresChange = PRESCHANGE_AUTO;
             if( maMF_ADVANCE_AUTO_AFTER.IsEnabled())
             {
-//                 sal_uInt16 nDigits = maMF_ADVANCE_AUTO_AFTER.GetDecimalDigits();
                 aResult.mnTime = static_cast<long>(maMF_ADVANCE_AUTO_AFTER.GetValue());
-                // / static_cast< sal_uInt16 >( pow( 10.0, static_cast< double >( nDigits )));
                 aResult.mbTimeAmbiguous = false;
             }
         }
@@ -1319,3 +1313,5 @@ IMPL_LINK( SlideTransitionPane, LateInitCallback, Timer*, EMPTYARG )
 
 
 } //  namespace sd
+
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
